About
=====

`Max M`_ had often needed to parse and generate iCalendar files. Finally, he got
tired of writing ad-hoc tools. This package is his attempt at making an
iCalendar package for Python. The inspiration has come from the email package
in the standard lib, which he thinks is pretty simple, yet efficient and
powerful.

The icalendar package is an RFC 5545-compatible parser/generator for iCalendar files.

.. _`Max M`: http://www.mxm.dk
.. _`RFC 2445`: https://tools.ietf.org/html/rfc2445
.. _`RFC 5545`: https://tools.ietf.org/html/rfc5545
